import router from './router'
import store from './store'
import { Message } from 'element-ui'
import { getToken } from '@/utils/auth'
import getPageTitle from '@/utils/get-page-title'

const whiteList = ['/login', '/auth-redirect']
const toSupplier = ['/supplier/list', '/supplier']

router.beforeEach(async(to, from, next) => {
  // 设置页面名称
  document.title = getPageTitle(to.meta.title)
  // 获取token
  const hasToken = getToken()

  if (hasToken) {
    /**
     * 满足要求则关闭所有标签，防止代理数据冲突
     * 条件：1、sotre中存有代理数据 即 proxyInfo !== null
     *      2、即将跳转的页面为 /supplier/list 或者 /supplier
     */
    if (toSupplier.includes(to.path) && store.getters.proxyInfo !== null) {
      store.dispatch('tagsView/delAllProxyView')
      store.commit('user/SET_PROXY_INFO', null)
    }

    if (to.path === '/login') {
      // 在登录状态下访问login页面，直接跳转到首页
      next()
    } else {
      // 加载国家列表
      store.dispatch('app/setCountry')
      // 是否需要初始化路由
      const hasInitRouter = store.getters.initRouter
      if (hasInitRouter) {
        next()
      } else {
        try {
          // 设置路由的初始化状态
          store.commit('permission/SET_INITROUTER', true)

          // 通过
          const accessRoutes = await store.dispatch('permission/generateRoutes', store.getters.roles)

          // 设置路由
          router.addRoutes(accessRoutes)

          // 初始化会话信息 条件：当前用户为管理员 && socket对象已创建成功
          if (!store.getters.socketState && store.getters.userIdentity === 1) {
            store.dispatch('webSocket/initMessage')
          }

          next({ ...to, replace: true })
        } catch (error) {
          store.dispatch('user/resetToken')
          Message.error(error || '未知错误，请重新登录')
          next(`/login?redirect=${to.path}`)
        }
      }
    }
  } else {
    // token不存在并且访问的路由非拦截路由
    if (whiteList.indexOf(to.path) !== -1) {
      // 允许访问
      next()
    } else {
      // 跳转到登录页面
      Message({ message: '登录失效，请重新登录！', duration: 1500 })
      next(`/login`)
      return
    }
  }
})
