import Vue from 'vue'
import Vuex from 'vuex'
import getters from './getters'
import { closeWebSocket } from '@/utils/WebSocketUtil'

Vue.use(Vuex)

// 动态加载modules
const modulesFiles = require.context('./modules', true, /\.js$/)

const modules = modulesFiles.keys().reduce((modules, modulePath) => {
  const moduleName = modulePath.replace(/^\.\/(.*)\.\w+$/, '$1')
  const value = modulesFiles(modulePath)
  modules[moduleName] = value.default
  return modules
}, {})

// 创建store
const store = new Vuex.Store({
  modules,
  getters,
  actions: {
    // 重置部分state
    resetState({ commit }) {
      commit('permission/RESET_STATE')
      commit('tagsView/RESET_STATE')
      closeWebSocket()
    }
  }
})

export default store
